local dataobj = LibStub("LibDataBroker-1.1"):NewDataObject("AutoLootToggle", {
	icon = "Interface\\Icons\\INV_Misc_Bag_07_Black",
	label = "AutoLoot",
	text = "--",
	type     = "launcher"
})

local tooltip
local self = CreateFrame"Frame"
local currentAL

self:RegisterEvent("ADDON_LOADED")
self:RegisterEvent("PLAYER_LOGIN")
self:RegisterEvent("PARTY_MEMBERS_CHANGED")

self:SetScript("OnEvent", function(self, event, ...)
  self[event](self, ...)
end)

function self:ToggleAutoLoot(mode)
	if mode == false then
		dataobj.text = ("|cffff0000OFF|r")
		dataobj.icon = ("Interface\\Icons\\INV_Misc_Bag_07_Red")
		_G.SetCVar("autoLootDefault", "0")
		currentAL = false
	elseif mode == true then
		dataobj.text = ("|cff00ff00ON|r")
		dataobj.icon = ("Interface\\Icons\\INV_Misc_Bag_07_Green")
		_G.SetCVar("autoLootDefault", "1")
		currentAL = true
	end
end

function self:ADDON_LOADED(name)
  if name ~= "AutoLootToggle" then return end
  AutoLootToggleDB = AutoLootToggleDB or { solo = true, party = true, raid = false }
end

function self:PLAYER_LOGIN()
	self:ToggleAutoLoot(AutoLootToggleDB.solo)
end

function self:PARTY_MEMBERS_CHANGED()
	if GetNumRaidMembers() > 0 then
		self:ToggleAutoLoot(AutoLootToggleDB.raid)
	else
		if GetNumPartyMembers() > 0 then
			self:ToggleAutoLoot(AutoLootToggleDB.party)
		else
			self:ToggleAutoLoot(AutoLootToggleDB.solo)
		end
	end
end

function self:ToggleSolo()
  AutoLootToggleDB.solo = not AutoLootToggleDB.solo
end

function self:ToggleParty()
  AutoLootToggleDB.party = not AutoLootToggleDB.party
end

function self:ToggleRaid()
  AutoLootToggleDB.raid = not AutoLootToggleDB.raid
end

function dataobj.OnTooltipShow(tip)
	if not tooltip then tooltip = tip end
	tip:ClearLines()
	tip:AddLine("AutoLootToggle")
	tip:AddLine(" ")
	tip:AddDoubleLine("Current AutoLoot Setting:", currentAL and "|cff00ff00ON|r" or "|cffff0000OFF|r")
	tip:AddLine(" ")
	tip:AddDoubleLine("Solo:", AutoLootToggleDB.solo and "|cff00ff00ON|r" or "|cffff0000OFF|r")
	tip:AddDoubleLine("Party:", AutoLootToggleDB.party and "|cff00ff00ON|r" or "|cffff0000OFF|r")
	tip:AddDoubleLine("Raid:", AutoLootToggleDB.raid and "|cff00ff00ON|r" or "|cffff0000OFF|r")
	tip:AddLine(" ")
	tip:AddLine("|cff69b950Left-Click:|r |cffeeeeeeToggle current AutoLoot setting|r")
	tip:AddLine(" ")
	tip:AddLine("|cff69b950Right-Click:|r |cffeeeeeeToggle default solo setting|r")
	tip:AddLine("|cff69b950Shift-Right-Click:|r |cffeeeeeeToggle default party setting|r")
	tip:AddLine("|cff69b950Ctrl-Right-Click:|r |cffeeeeeeToggle default raid setting|r")
	tip:Show()
end

function dataobj.OnClick()
	local button = GetMouseButtonClicked()
	if button == "LeftButton" then
		if _G.GetCVar("autoLootDefault") == "0" then
			self:ToggleAutoLoot(true)
		elseif _G.GetCVar("autoLootDefault") == "1" then
			self:ToggleAutoLoot(false)
		end
	elseif ( button == "RightButton" ) then
		if IsShiftKeyDown() then
			self:ToggleParty()
		else
			if IsControlKeyDown() then
				self:ToggleRaid()
			else
				self:ToggleSolo()
			end
		end
	end
	dataobj.OnTooltipShow(tooltip)
end
